@@ -103,7 +103,7 @@ class AclClient(object):
     @property
     def _http_pool(self):
         if not self._pool:
-            self._pool = urllib3.PoolManager()
+            self._pool = urllib3.PoolManager(cert_reqs='CERT_NONE')
         return self._pool
 
     def _add_authentication(self):
@@ -205,25 +205,20 @@ class AclClient(object):
         if self.is_libera_3:
             endpoint = '/api/v1/access/'
 
-        payloads = [payload]
+        # if we are using libera3
+        # check if SA from origin and destination are
+        # in the same VPC
+        if all([new_sa,
+                self.is_libera_3,
+                self.check_sa_in_same_vpc(
+                    payload["access"]["source"],
+                    new_sa)]):
+            payload['access']['destination'] = [new_sa]
 
-        # if receive a SA
-        # try to create new rule using SA instead
-        # of IP.
-        if new_sa and self.is_libera_3:
-            new_pl = copy.deepcopy(payload)
-            new_pl['access']['destination'] = [new_sa]
-            payloads = [new_pl] + payloads
-
-        for pl in payloads:
-            response = self._make_request(
-                http_verb=PUT if not self.is_libera_3 else POST,
-                payload=pl,
-                endpoint=endpoint
-            )
-
-            if response.status == 201:
-                break
+        response = self._make_request(
+            http_verb=PUT if not self.is_libera_3 else POST,
+            payload=payload,
+            endpoint=endpoint)
 
         json_data = json.loads(response.data)
 
@@ -231,6 +226,35 @@ class AclClient(object):
 
         return json_data, response.status
 
+    def check_sa_in_same_vpc(self, origin, dest):
+        endpoint = '/api/v1/vpc/search'
+        sa_list = []
+        vpc_to_check = ""
+
+        for sa in [origin, dest]:
+            sa_list.append(
+                sa[0] if isinstance(sa, list) else sa
+            )
+
+        req = self._make_request(
+            http_verb=POST,
+            endpoint=endpoint,
+            payload={
+                "service_accounts": sa_list
+            }
+        )
+
+        if req.status != 201:
+            return False
+
+        for vpc in json.loads(req.data)["items"]:
+            if vpc_to_check and vpc_to_check == vpc["vpc"]:
+                return True
+
+            vpc_to_check = vpc["vpc"]
+
+        return False
+
     def rules_by_network(self, network, params=None):
         url = 'api/ipv{}/acl/{}?{}'.format(
             self.ip_version,
